@@ -2,13 +2,9 @@
 #
 #  Net::Server::SIG - Safer signals
 #
-#  $Id: SIG.pm,v 1.8 2013/01/10 06:11:41 rhandom Exp $
+#  Copyright (C) 2001-2022
 #
-#  Copyright (C) 2001-2012
-#
-#    Paul Seamons
-#    paul@seamons.com
-#    http://seamons.com/
+#    Paul Seamons <paul@seamons.com>
 #
 #  This package may be distributed under the terms of either the
 #  GNU General Public License
@@ -22,6 +18,7 @@
 package Net::Server::SIG;
 
 use strict;
+use Carp qw(croak);
 use vars qw($VERSION @ISA @EXPORT_OK
             %_SIG %_SIG_SUB);
 use Exporter ();
@@ -31,7 +28,7 @@ $VERSION   = '0.03';
 @EXPORT_OK = qw(register_sig unregister_sig check_sigs);
 
 sub register_sig {
-    die 'Usage: register_sig( SIGNAME => \&code_ref )' if @_ % 2;
+    croak 'Usage: register_sig( SIGNAME => \&code_ref )' if @_ % 2;
     if (@_ > 2) {
         register_sig(shift(),shift()) while @_;
         return;
@@ -50,14 +47,14 @@ sub register_sig {
             delete $_SIG_SUB{$sig};
             $SIG{$sig} = 'IGNORE';
         } else {
-            die "Scalar argument limited to \"DEFAULT\" and \"IGNORE\".";
+            croak 'Scalar argument limited to "DEFAULT" and "IGNORE"';
         }
     } elsif ($ref eq 'CODE') {
         $_SIG{$sig} = 0;
         $_SIG_SUB{$sig} = $code_ref;
-        $SIG{$sig} = sub{ $Net::Server::SIG::_SIG{$_[0]} = 1; };
+        $SIG{$sig} = sub{ $Net::Server::SIG::_SIG{$sig} = 1 };
     } else {
-        die "Unsupported sig type -- must be 'DEFAULT' or a code ref.";
+        croak "Unsupported sig type -- must be 'DEFAULT' or a code ref.";
     }
 }
 
@@ -137,7 +134,7 @@ to fix the unsafe problem.  If a process is blocking on select() any
 signal will short circuit the select.  Using this concept,
 Net::Server::SIG does the least work possible (changing one bit from 0
 to 1).  And depends upon the actual processing of the signals to take
-place immediately after the the select call via the "check_sigs"
+place immediately after the select call via the "check_sigs"
 function.  See the example shown above and also see the sigtest.pl
 script located in the examples directory of this distribution.
 
@@ -161,9 +158,9 @@ register_sig(SIG,'DEFAULT')
 
 =item C<check_sigs()>
 
-Checks to see if any registered signals have occured.  If so, it will
+Checks to see if any registered signals have occurred.  If so, it will
 play the registered code ref for that signal.  Return value is array
-containing any SIGNAL names that had occured.
+containing any SIGNAL names that had occurred.
 
 =item C<sig_is_registered($SIG)>
 
